summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/combobox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/combobox.h')
-rw-r--r--kalarm/lib/combobox.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kalarm/lib/combobox.h b/kalarm/lib/combobox.h
index 5f8f4cc3..3d5ff13e 100644
--- a/kalarm/lib/combobox.h
+++ b/kalarm/lib/combobox.h
@@ -40,16 +40,16 @@ class ComboBox : public TQComboBox
TQ_OBJECT
public:
/** Constructor.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- explicit ComboBox(TQWidget* tqparent = 0, const char* name = 0);
+ explicit ComboBox(TQWidget* parent = 0, const char* name = 0);
/** Constructor.
* @param rw True for a read-write combo box, false for a read-only combo box.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- explicit ComboBox(bool rw, TQWidget* tqparent = 0, const char* name = 0);
+ explicit ComboBox(bool rw, TQWidget* parent = 0, const char* name = 0);
/** Returns true if the widget is read only. */
bool isReadOnly() const { return mReadOnly; }
/** Sets whether the combo box is read-only for the user. If read-only,
@@ -40,16 +40,16 @@ class ComboBox : public TQComboBox
public:
/** Constructor.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/
@@ -40,16 +40,16 @@ class ComboBox : public TQComboBox
/** Constructor.
* @param rw True for a read-write combo box, false for a read-only combo box.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/